==> libreoffice-fresh-sdk-25.2.3-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel =
[
    [ "UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a85c9847c6ec77e673c618e26b2aa0746", null ],
    [ "Border", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a54d3ff280d892218d71e667f81ce99d4", null ],
    [ "BorderColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a79f9492eb784a2ae0323d4d31b179a8a", null ],
    [ "EditMask", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a3d01cbf22eccde421fb60f4ac6885569", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "FontDescriptor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a9e110c55c0a3426a353ded5f029cd4e0", null ],
    [ "FontEmphasisMark", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#ac5c5781ab84a14cafec66b192fbdeae9", null ],
    [ "FontRelief", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#ac2b8dcc269c9ef6d27978db9b76caa43", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "HideInactiveSelection", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a4a7a3ff65ecc704925e4c0692da1baa1", null ],
    [ "HighlightColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a9f6d16e9f74137fc9e3158e8928c8572", null ],
    [ "HighlightTextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a9b462e58b5c1c9058cd57041eb9c83e2", null ],
    [ "LiteralMask", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a2de783e8bfa00a5579857feb6890fda6", null ],
    [ "MaxTextLen", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#abd771228d4414f63f6f080633f59c93e", null ],
    [ "MouseWheelBehavior", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#aa612def382bea69d1c4e47f279268ae2", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "ReadOnly", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a27f7199b1316915a80fec16a3c215148", null ],
    [ "StrictFormat", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a98fd1071b232d41231a91eb0bb3ac4b2", null ],
    [ "Tabstop", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a58b62919451b71e65ecb718a57c053e5", null ],
    [ "Text", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#ab4726c7c06ae41233e679361293b4173", null ],
    [ "TextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a01c58818488ca5e1d235d71b625efa0e", null ],
    [ "TextLineColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a7de6f39eb42c328f77d4db6f6861bd6b", null ],
    [ "VerticalAlign", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#aeeee894b4f8f059ee92ccef71579845a", null ],
    [ "WritingMode", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a002026db708f25e491f177b8f102f172", null ]
];

==> libreoffice-fresh-sdk-25.8.4-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel =
[
    [ "com::sun::star::awt::UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a85c9847c6ec77e673c618e26b2aa0746", null ],
    [ "Border", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a54d3ff280d892218d71e667f81ce99d4", null ],
    [ "BorderColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a79f9492eb784a2ae0323d4d31b179a8a", null ],
    [ "EditMask", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a3d01cbf22eccde421fb60f4ac6885569", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "FontDescriptor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a9e110c55c0a3426a353ded5f029cd4e0", null ],
    [ "FontEmphasisMark", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#ac5c5781ab84a14cafec66b192fbdeae9", null ],
    [ "FontRelief", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#ac2b8dcc269c9ef6d27978db9b76caa43", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "HideInactiveSelection", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a4a7a3ff65ecc704925e4c0692da1baa1", null ],
    [ "HighlightColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a9f6d16e9f74137fc9e3158e8928c8572", null ],
    [ "HighlightTextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a9b462e58b5c1c9058cd57041eb9c83e2", null ],
    [ "LiteralMask", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a2de783e8bfa00a5579857feb6890fda6", null ],
    [ "MaxTextLen", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#abd771228d4414f63f6f080633f59c93e", null ],
    [ "MouseWheelBehavior", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#aa612def382bea69d1c4e47f279268ae2", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "ReadOnly", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a27f7199b1316915a80fec16a3c215148", null ],
    [ "StrictFormat", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a98fd1071b232d41231a91eb0bb3ac4b2", null ],
    [ "Tabstop", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a58b62919451b71e65ecb718a57c053e5", null ],
    [ "Text", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#ab4726c7c06ae41233e679361293b4173", null ],
    [ "TextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a01c58818488ca5e1d235d71b625efa0e", null ],
    [ "TextLineColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a7de6f39eb42c328f77d4db6f6861bd6b", null ],
    [ "VerticalAlign", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#aeeee894b4f8f059ee92ccef71579845a", null ],
    [ "WritingMode", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html#a002026db708f25e491f177b8f102f172", null ]
];
